@@ -5,8 +5,10 @@ from django.utils.deconstruct import deconstructible
 class ViewMigration(object):
 
     def __init__(self, view_definition: str, table_name: str, engine=None):
-        self.view_engine = engine
         self.db_engine = settings.DATABASES['default']['ENGINE']
+        # if provided engine is None, then we assuming that engine is same as db engine.
+        # We do that to keep backward compatibility.
+        self.view_engine = engine or self.db_engine
         self.view_definition = view_definition
         self.table_name = table_name
 
